@@ -1,32 +1,26 @@
 //===-- REPL.h --------------------------------------------------*- C++ -*-===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is distributed under the University of Illinois Open Source
-// License. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
 #ifndef lldb_REPL_h
 #define lldb_REPL_h
 
-// C Includes
-// C++ Includes
 #include <string>
 
-// Other libraries and framework includes
-// Project includes
-#include "lldb/../../source/Commands/CommandObjectExpression.h"
+#include "lldb/Core/IOHandler.h"
 #include "lldb/Interpreter/OptionGroupFormat.h"
 #include "lldb/Interpreter/OptionGroupValueObjectDisplay.h"
+#include "lldb/Target/Target.h"
 
 namespace lldb_private {
 
 class REPL : public IOHandlerDelegate {
 public:
-  //----------------------------------------------------------------------
   // See TypeSystem.h for how to add subclasses to this.
-  //----------------------------------------------------------------------
   enum LLVMCastKind { eKindClang, eKindSwift, eKindGo, kNumKinds };
 
   LLVMCastKind getKind() const { return m_kind; }
@@ -35,32 +29,30 @@ public:
 
   ~REPL() override;
 
-  //------------------------------------------------------------------
   /// Get a REPL with an existing target (or, failing that, a debugger to use),
   /// and (optional) extra arguments for the compiler.
   ///
-  /// @param[out] error
+  /// \param[out] Status
   ///     If this language is supported but the REPL couldn't be created, this
   ///     error is populated with the reason.
   ///
-  /// @param[in] language
+  /// \param[in] language
   ///     The language to create a REPL for.
   ///
-  /// @param[in] debugger
+  /// \param[in] debugger
   ///     If provided, and target is nullptr, the debugger to use when setting
   ///     up a top-level REPL.
   ///
-  /// @param[in] target
+  /// \param[in] target
   ///     If provided, the target to put the REPL inside.
   ///
-  /// @param[in] repl_options
+  /// \param[in] repl_options
   ///     If provided, additional options for the compiler when parsing REPL
   ///     expressions.
   ///
-  /// @return
+  /// \return
   ///     The range of the containing object in the target process.
-  //------------------------------------------------------------------
-  static lldb::REPLSP Create(Error &Error, lldb::LanguageType language,
+  static lldb::REPLSP Create(Status &Status, lldb::LanguageType language,
                              Debugger *debugger, Target *target,
                              const char *repl_options);
 
@@ -73,9 +65,8 @@ public:
     m_varobj_options = options;
   }
 
-  void
-  SetCommandOptions(const CommandObjectExpression::CommandOptions &options) {
-    m_command_options = options;
+  void SetEvaluateOptions(const EvaluateExpressionOptions &options) {
+    m_expr_options = options;
   }
 
   void SetCompilerOptions(const char *options) {
@@ -85,12 +76,10 @@ public:
 
   lldb::IOHandlerSP GetIOHandler();
 
-  Error RunLoop();
+  Status RunLoop();
 
-  //------------------------------------------------------------------
   // IOHandler::Delegate functions
-  //------------------------------------------------------------------
-  void IOHandlerActivated(IOHandler &io_handler) override;
+  void IOHandlerActivated(IOHandler &io_handler, bool interactive) override;
 
   bool IOHandlerInterrupt(IOHandler &io_handler) override;
 
@@ -114,19 +103,15 @@ public:
   void IOHandlerInputComplete(IOHandler &io_handler,
                               std::string &line) override;
 
-  int IOHandlerComplete(IOHandler &io_handler, const char *current_line,
-                        const char *cursor, const char *last_char,
-                        int skip_first_n_matches, int max_matches,
-                        StringList &matches) override;
+  void IOHandlerComplete(IOHandler &io_handler,
+                         CompletionRequest &request) override;
 
 protected:
   static int CalculateActualIndentation(const StringList &lines);
 
-  //----------------------------------------------------------------------
   // Subclasses should override these functions to implement a functional REPL.
-  //----------------------------------------------------------------------
 
-  virtual Error DoInitialization() = 0;
+  virtual Status DoInitialization() = 0;
 
   virtual ConstString GetSourceFileBasename() = 0;
 
@@ -150,7 +135,7 @@ protected:
 
   OptionGroupFormat m_format_options = OptionGroupFormat(lldb::eFormatDefault);
   OptionGroupValueObjectDisplay m_varobj_options;
-  CommandObjectExpression::CommandOptions m_command_options;
+  EvaluateExpressionOptions m_expr_options;
   std::string m_compiler_options;
 
   bool m_enable_auto_indent = true;
